@@ -18,53 +18,58 @@ caretSLOPE <- function() {
     label = "SLOPE",
     library = c("SLOPE", "Matrix"),
     type = c("Regression", "Classification"),
-
-    parameters = data.frame(parameter = c("alpha", "q"),
-                            class = rep("numeric", 2),
-                            label = c("alpha", "False discovery rate")),
-
+    parameters = data.frame(
+      parameter = c("alpha", "q"),
+      class = rep("numeric", 2),
+      label = c("alpha", "False discovery rate")
+    ),
     grid = function(x, y, len = NULL, search = "grid") {
-
-      s <- 0.2*(1 - 1/len)
+      s <- 0.2 * (1 - 1 / len)
       q <- seq(-s, s, length.out = len) + 0.2
 
       numLev <- if (is.character(y) | is.factor(y)) length(levels(y)) else NA
 
-      if (!is.na(numLev))
+      if (!is.na(numLev)) {
         fam <- ifelse(numLev > 2, "multinomial", "binomial")
-      else
+      } else {
         fam <- "gaussian"
+      }
 
       fit <- SLOPE::SLOPE(x,
-                          y,
-                          family = fam,
-                          path_length = len + 2,
-                          scale = FALSE,
-                          center = FALSE)
+        y,
+        family = fam,
+        path_length = len + 2,
+        scale = FALSE,
+        center = FALSE
+      )
 
       alpha <- fit$alpha
       alpha <- alpha[-c(1, length(alpha))]
       alpha <- alpha[1:min(length(alpha), len)]
 
       if (search == "grid") {
-        out <- expand.grid(alpha = alpha,
-                           q = q)
+        out <- expand.grid(
+          alpha = alpha,
+          q = q
+        )
       } else {
         q <- stats::runif(0.01, 0.4, len)
 
-        alpha <- exp(stats::runif(log(min(alpha)),
-                                  log(max(alpha)),
-                                  len))
+        alpha <- exp(stats::runif(
+          log(min(alpha)),
+          log(max(alpha)),
+          len
+        ))
 
-        out <- data.frame(alpha = alpha,
-                          q = q)
+        out <- data.frame(
+          alpha = alpha,
+          q = q
+        )
       }
 
       out
     },
-
     loop = function(grid) {
-
       q <- unique(grid$q)
       loop <- data.frame(q = q)
       loop$alpha <- NA
@@ -79,15 +84,14 @@ caretSLOPE <- function() {
 
       list(loop = loop, submodels = submodels)
     },
-
     fit = function(x, y, wts, param, lev, last, weights, classProbs, ...) {
-
       dots <- list(...)
 
-      numLev <- if (is.character(y) | is.factor(y))
+      numLev <- if (is.character(y) | is.factor(y)) {
         length(levels(y))
-      else
+      } else {
         NA
+      }
 
       if (all(names(dots) != "family")) {
         if (!is.na(numLev)) {
@@ -109,106 +113,116 @@ caretSLOPE <- function() {
 
       out <- do.call(SLOPE::SLOPE, dots)
 
-      if (!is.na(param$alpha[1]))
+      if (!is.na(param$alpha[1])) {
         out$alphaOpt <- param$alpha[1]
+      }
 
       out
     },
-
     predict = function(modelFit, newdata, preProc = NULL, submodels = NULL) {
       library(SLOPE)
 
-      if (!is.matrix(newdata))
+      if (!is.matrix(newdata)) {
         newdata <- Matrix::as.matrix(newdata)
+      }
 
       if (length(modelFit$obsLevels) < 2) {
         out <- stats::predict(modelFit,
-                              newdata,
-                              alpha = modelFit$alphaOpt)
+          newdata,
+          alpha = modelFit$alphaOpt
+        )
       } else {
         out <- stats::predict(modelFit,
-                              newdata,
-                              alpha = modelFit$alphaOpt,
-                              type = "class")
+          newdata,
+          alpha = modelFit$alphaOpt,
+          type = "class"
+        )
       }
 
-      if (is.matrix(out))
+      if (is.matrix(out)) {
         out <- out[, 1]
+      }
 
       if (!is.null(submodels)) {
         if (length(modelFit$obsLevels) < 2) {
           tmp <- stats::predict(modelFit,
-                                newdata,
-                                alpha = submodels$alpha)
+            newdata,
+            alpha = submodels$alpha
+          )
           tmp <- as.list(as.data.frame(tmp))
         } else {
           tmp <- stats::predict(modelFit,
-                                newdata,
-                                alpha = submodels$alpha,
-                                type = "class")
-          tmp <- if (is.matrix(tmp))
+            newdata,
+            alpha = submodels$alpha,
+            type = "class"
+          )
+          tmp <- if (is.matrix(tmp)) {
             as.data.frame(tmp, stringsAsFactors = FALSE)
-          else
+          } else {
             as.character(tmp)
+          }
           tmp <- as.list(tmp)
         }
         out <- c(list(out), tmp)
       }
       out
-
     },
-
     prob = function(modelFit, newdata, preProc = NULL, submodels = NULL) {
-      obsLevels <- if("class_names" %in% names(modelFit))
+      obsLevels <- if ("class_names" %in% names(modelFit)) {
         modelFit$class_names
-      else
+      } else {
         NULL
+      }
 
       probs <- stats::predict(modelFit,
-                              Matrix::as.matrix(newdata),
-                              alpha = modelFit$alpha,
-                              type = "response")
+        Matrix::as.matrix(newdata),
+        alpha = modelFit$alpha,
+        type = "response"
+      )
 
       if (length(obsLevels) == 2) {
         probs <- as.vector(probs)
-        probs <- as.data.frame(cbind(1-probs, probs))
+        probs <- as.data.frame(cbind(1 - probs, probs))
         colnames(probs) <- modelFit$obsLevels
       } else {
-        probs <- as.data.frame(probs[,,1,drop = FALSE])
+        probs <- as.data.frame(probs[, , 1, drop = FALSE])
         names(probs) <- modelFit$obsLevels
       }
 
       if (!is.null(submodels)) {
         tmp <- stats::predict(modelFit,
-                              Matrix::as.matrix(newdata),
-                              alpha = submodels$alpha,
-                              type = "response")
+          Matrix::as.matrix(newdata),
+          alpha = submodels$alpha,
+          type = "response"
+        )
 
-        if(length(obsLevels) == 2) {
+        if (length(obsLevels) == 2) {
           tmp <- as.list(as.data.frame(tmp))
           tmp <- lapply(tmp,
-                        function(x, lev) {
-                          x <- as.vector(x)
-                          tmp <- data.frame(1-x, x)
-                          names(tmp) <- lev
-                          tmp
-                        },
-                        lev = modelFit$obsLevels)
-        } else tmp <- apply(tmp, 3, function(x) data.frame(x))
+            function(x, lev) {
+              x <- as.vector(x)
+              tmp <- data.frame(1 - x, x)
+              names(tmp) <- lev
+              tmp
+            },
+            lev = modelFit$obsLevels
+          )
+        } else {
+          tmp <- apply(tmp, 3, function(x) data.frame(x))
+        }
         probs <- if (is.list(tmp)) c(list(probs), tmp) else list(probs, tmp)
       }
       probs
-
     },
-
     predictors = function(x, alpha = NULL, ...) {
       if (is.null(alpha)) {
-        if (length(alpha) > 1)
+        if (length(alpha) > 1) {
           stop("Only one value of alpha is allowed right now")
+        }
 
         if (!is.null(x$alphaOpt)) {
           alpha <- x$alphaOpt
-        } else  {
+        } else {
           stop("must supply a value of alpha")
         }
       }
@@ -225,11 +239,11 @@ caretSLOPE <- function() {
 
       out
     },
-
     varImp = function(object, alpha = NULL, ...) {
       if (is.null(alpha)) {
-        if (length(alpha) > 1)
+        if (length(alpha) > 1) {
           stop("Only one value of alpha is allowed right now")
+        }
 
         if (!is.null(object$alphaOpt)) {
           alpha <- object$alphaOpt
@@ -244,29 +258,26 @@ caretSLOPE <- function() {
       out <- abs(out[rownames(out) != "(Intercept)", , drop = FALSE])
       out
     },
-
     levels = function(x) {
-      if (any(names(x) == "obsLevels"))
+      if (any(names(x) == "obsLevels")) {
         x$obsLevels
-      else
+      } else {
         NULL
+      }
     },
-
     sort = function(x) {
-      x[order(-x$alpha, x$q),]
+      x[order(-x$alpha, x$q), ]
     },
-
     trim = function(x) {
       x$call <- NULL
       x
     },
-
-    tags = c("Generalized Linear Model",
-             "Implicit Feature Selection",
-             "L1 Regularization",
-             "Linear Classifier",
-             "Linear Regression")
+    tags = c(
+      "Generalized Linear Model",
+      "Implicit Feature Selection",
+      "L1 Regularization",
+      "Linear Classifier",
+      "Linear Regression"
+    )
   )
 }
-
-
