@@ -1,11 +1,7 @@
 #pragma once
 
-#include <RcppArmadillo.h>
 #include "family.h"
-#include "../results.h"
-
-using namespace Rcpp;
-using namespace arma;
+#include <RcppArmadillo.h>
 
 class Binomial : public Family
 {
@@ -15,24 +11,30 @@ public:
     : Family(std::forward<Ts>(args)...)
   {}
 
-  double primal(const mat& y, const mat& lin_pred)
+  double primal(const arma::mat& y, const arma::mat& lin_pred)
   {
+    using namespace arma;
+
     return accu(trunc_log(1.0 + trunc_exp(-y % lin_pred)));
   }
 
-  double dual(const mat& y, const mat& lin_pred)
+  double dual(const arma::mat& y, const arma::mat& lin_pred)
   {
+    using namespace arma;
+
     const vec r = 1.0 / (1.0 + trunc_exp(y % lin_pred));
     return dot(r - 1.0, trunc_log(1.0 - r)) - dot(r, trunc_log(r));
   }
 
-  mat pseudoGradient(const mat& y, const mat& lin_pred)
+  arma::mat pseudoGradient(const arma::mat& y, const arma::mat& lin_pred)
   {
-    return -y / (1.0 + trunc_exp(y % lin_pred));
+    return -y / (1.0 + arma::trunc_exp(y % lin_pred));
   }
 
-  rowvec fitNullModel(const mat& y, const uword n_classes)
+  arma::rowvec fitNullModel(const arma::mat& y, const arma::uword n_classes)
   {
+    using namespace arma;
+
     double pmin = 1e-9;
     double pmax = 1 - pmin;
 
