@@ -1,11 +1,7 @@
 #pragma once
 
-#include <RcppArmadillo.h>
 #include "family.h"
-#include "../results.h"
-
-using namespace Rcpp;
-using namespace arma;
+#include <RcppArmadillo.h>
 
 class Multinomial : public Family
 {
@@ -15,42 +11,50 @@ public:
     : Family(std::forward<Ts>(args)...)
   {}
 
-  double primal(const mat& y, const mat& lin_pred)
+  double primal(const arma::mat& y, const arma::mat& lin_pred)
   {
+    using namespace arma;
+
     // logsumexp bit
     vec lp_max = max(lin_pred, 1);
-    vec lse = trunc_log(exp(-lp_max) +
+    vec lse    = trunc_log(exp(-lp_max) +
                         sum(trunc_exp(lin_pred.each_col() - lp_max), 1)) +
               lp_max;
 
     return accu(lse) - accu(y % lin_pred);
   }
 
-  double dual(const mat& y, const mat& lin_pred)
+  double dual(const arma::mat& y, const arma::mat& lin_pred)
   {
+    using namespace arma;
+
     vec lp_max = max(lin_pred, 1);
-    vec lse = trunc_log(exp(-lp_max) +
+    vec lse    = trunc_log(exp(-lp_max) +
                         sum(trunc_exp(lin_pred.each_col() - lp_max), 1)) +
               lp_max;
 
     return accu(lse) - accu(lin_pred % trunc_exp(lin_pred.each_col() - lse));
   }
 
-  mat pseudoGradient(const mat& y, const mat& lin_pred)
+  arma::mat pseudoGradient(const arma::mat& y, const arma::mat& lin_pred)
   {
+    using namespace arma;
+
     vec lp_max = max(lin_pred, 1);
-    vec lse = trunc_log(exp(-lp_max) +
+    vec lse    = trunc_log(exp(-lp_max) +
                         sum(trunc_exp(lin_pred.each_col() - lp_max), 1)) +
               lp_max;
 
     return trunc_exp(lin_pred.each_col() - lse) - y;
   }
 
-  rowvec fitNullModel(const mat& y, const uword n_classes)
+  arma::rowvec fitNullModel(const arma::mat& y, const arma::uword n_classes)
   {
+    using namespace arma;
+
     const uword m = y.n_cols;
 
-    rowvec mu = mean(y);
+    rowvec mu     = mean(y);
     rowvec log_mu = trunc_log(mu);
 
     return log_mu - accu(log_mu + trunc_log(1 - accu(mu))) / (m + 1);
